@@ -1,6 +1,6 @@
 /* This file is part of the KDE Project
    Copyright (c) 2008-2010 Sebastian Trueg <trueg@kde.org>
-   Copyright (c) 2013      Vishesh Handa <me@vhanda.in>
+   Copyright (c) 2013-2014 Vishesh Handa <me@vhanda.in>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -113,6 +113,8 @@ QStringList FileIndexerConfig::excludeFilters() const
 
         // write the config directly since the KCM does not have support for the version yet
         // TODO: make this class public and use it in the KCM
+        KConfig config(m_config.name());
+        KConfigGroup cfg = config.group("General");
         cfg.writeEntry("exclude filters", QStringList::fromSet(filters));
         cfg.writeEntry("exclude filters version", defaultExcludeFilterListVersion());
     }
@@ -129,8 +131,8 @@ bool FileIndexerConfig::indexHiddenFilesAndFolders() const
 
 void FileIndexerConfig::slotConfigDirty()
 {
-    if (forceConfigUpdate())
-        Q_EMIT configChanged();
+    forceConfigUpdate();
+    Q_EMIT configChanged();
 }
 
 
@@ -278,38 +280,8 @@ void cleanupList(QList<QPair<QString, bool> >& result)
 }
 }
 
-
-void FileIndexerConfig::fillIncludeFolderChanges(const FileIndexerConfig::Entry& entry, const QSet<QString>& include, QStringList* includeAdded, QStringList* includeRemoved)
+void FileIndexerConfig::buildFolderCache()
 {
-    QStringList added = QSet<QString>(include).subtract(entry.includes).toList();
-    QStringList removed = QSet<QString>(entry.includes).subtract(include).toList();
-
-    if (includeAdded)
-        includeAdded->append(added);
-
-    if (includeRemoved)
-        includeRemoved->append(removed);
-}
-
-void FileIndexerConfig::fillExcludeFolderChanges(const FileIndexerConfig::Entry& entry, const QSet<QString>& exclude, QStringList* excludeAdded, QStringList* excludeRemoved)
-{
-    QStringList added = QSet<QString>(exclude).subtract(entry.excludes).toList();
-    QStringList removed = QSet<QString>(entry.excludes).subtract(exclude).toList();
-
-    if (excludeAdded)
-        excludeAdded->append(added);
-
-    if (excludeRemoved)
-        excludeRemoved->append(removed);
-}
-
-
-bool FileIndexerConfig::buildFolderCache()
-{
-
-    //
-    // General folders
-    //
     KConfigGroup group = m_config.group("General");
     QStringList includeFoldersPlain = group.readPathEntry("folders", QStringList() << QDir::homePath());
     QStringList excludeFoldersPlain = group.readPathEntry("exclude folders", QStringList());
@@ -318,122 +290,30 @@ bool FileIndexerConfig::buildFolderCache()
     insertSortFolders(includeFoldersPlain, true, m_folderCache);
     insertSortFolders(excludeFoldersPlain, false, m_folderCache);
 
-    QStringList includeAdded;
-    QStringList includeRemoved;
-    QStringList excludeAdded;
-    QStringList excludeRemoved;;
-
-    QSet<QString> includeSet = includeFoldersPlain.toSet();
-    QSet<QString> excludeSet = excludeFoldersPlain.toSet();
-
-    Entry& generalEntry = m_entries[ QLatin1String("General") ];
-    fillIncludeFolderChanges(generalEntry, includeSet, &includeAdded, &includeRemoved);
-    fillExcludeFolderChanges(generalEntry, excludeSet, &excludeAdded, &excludeRemoved);
-
-    generalEntry.includes = includeSet;
-    generalEntry.excludes = excludeSet;
-
-    //
-    // Removable Media
-    //
-    QStringList groupList = m_config.groupList();
-    Q_FOREACH (const QString& groupName, groupList) {
-        if (!groupName.startsWith(QLatin1String("Device-")))
-            continue;
-
-        KConfigGroup group = m_config.group(groupName);
-        QString mountPath = group.readEntry("mount path", QString());
-        if (mountPath.isEmpty())
-            continue;
-
-        QStringList includes = group.readPathEntry("folders", QStringList());
-        QStringList excludes = group.readPathEntry("exclude folders", QStringList());
-
-        QStringList includeFoldersPlain;
-        Q_FOREACH (const QString& path, includes)
-            includeFoldersPlain << mountPath + path;
-
-        QStringList excludeFoldersPlain;
-        Q_FOREACH (const QString& path, excludes)
-            excludeFoldersPlain << mountPath + path;
-
-        insertSortFolders(includeFoldersPlain, true, m_folderCache);
-        insertSortFolders(excludeFoldersPlain, false, m_folderCache);
-
-        QSet<QString> includeSet = includeFoldersPlain.toSet();
-        QSet<QString> excludeSet = excludeFoldersPlain.toSet();
-
-        Entry& cacheEntry = m_entries[ groupName ];
-        fillIncludeFolderChanges(cacheEntry, includeSet, &includeAdded, &includeRemoved);
-        fillExcludeFolderChanges(cacheEntry, excludeSet, &excludeAdded, &excludeRemoved);
-
-        cacheEntry.includes = includeSet;
-        cacheEntry.excludes = excludeSet;
-    }
-
     cleanupList(m_folderCache);
-
-    bool changed = false;
-    if (!includeAdded.isEmpty() || !includeRemoved.isEmpty()) {
-        Q_EMIT includeFolderListChanged(includeAdded, includeRemoved);
-        changed = true;
-    }
-
-    if (!excludeAdded.isEmpty() || !excludeRemoved.isEmpty()) {
-        Q_EMIT excludeFolderListChanged(excludeAdded, excludeRemoved);
-        changed = true;
-    }
-
-    return changed;
 }
 
 
-bool FileIndexerConfig::buildExcludeFilterRegExpCache()
+void FileIndexerConfig::buildExcludeFilterRegExpCache()
 {
     QStringList newFilters = excludeFilters();
     m_excludeFilterRegExpCache.rebuildCacheFromFilterList(newFilters);
-
-    QSet<QString> newFilterSet = newFilters.toSet();
-    if (m_prevFileFilters != newFilterSet) {
-        m_prevFileFilters = newFilterSet;
-        Q_EMIT fileExcludeFiltersChanged();
-        return true;
-    }
-
-    return false;
 }
 
-bool FileIndexerConfig::buildMimeTypeCache()
+void FileIndexerConfig::buildMimeTypeCache()
 {
-    QStringList newMimeExcludes = m_config.group("General").readPathEntry("exclude mimetypes", defaultExcludeMimetypes());
-
-    QSet<QString> newMimeExcludeSet = newMimeExcludes.toSet();
-    if (m_excludeMimetypes != newMimeExcludeSet) {
-        m_excludeMimetypes = newMimeExcludeSet;
-        Q_EMIT mimeTypeFiltersChanged();
-        return true;
-    }
-
-    return false;
+    m_excludeMimetypes = m_config.group("General").readPathEntry("exclude mimetypes", defaultExcludeMimetypes()).toSet();
 }
 
-
-bool FileIndexerConfig::forceConfigUpdate()
+void FileIndexerConfig::forceConfigUpdate()
 {
     m_config.reparseConfiguration();
-    bool changed = false;
 
-    changed = buildFolderCache() || changed;
-    changed = buildExcludeFilterRegExpCache() || changed;
-    changed = buildMimeTypeCache() || changed;
+    buildFolderCache();
+    buildExcludeFilterRegExpCache();
+    buildMimeTypeCache();
 
-    bool hidden = m_config.group("General").readEntry("index hidden folders", false);
-    if (hidden != m_indexHidden) {
-        m_indexHidden = hidden;
-        changed = true;
-    }
-
-    return changed;
+    m_indexHidden = m_config.group("General").readEntry("index hidden folders", false);
 }
 
 void FileIndexerConfig::setInitialRun(bool isInitialRun)
