@@ -32,6 +32,7 @@ class FileIndexingQueue;
 class FileIndexerConfig;
 class CommitQueue;
 class EventMonitor;
+class SchedulerTest;
 
 /**
  * The IndexScheduler is responsible for controlling the indexing
@@ -104,7 +105,6 @@ private Q_SLOTS:
     void slotConfigChanged();
 
     void slotStartedIndexing();
-    void slotFinishedIndexing();
 
     // Event Monitor integration
     void slotScheduleIndexing();
@@ -118,8 +118,8 @@ private:
     // no signal is emitted twice
     void setIndexingStarted(bool started);
 
-    bool scheduleBasicQueue();
-    bool scheduleFileQueue();
+    bool shouldRunBasicQueue();
+    bool shouldRunFileQueue();
     void setStateFromEvent();
 
     bool m_indexing;
@@ -144,6 +144,8 @@ private:
     QString m_oldStatus;
 
     Database* m_db;
+
+    friend class SchedulerTest;
 };
 }
 
