@@ -46,13 +46,18 @@ private Q_SLOTS:
     void testSimpleSearchString();
     void testIncludeDir();
     void testRatings();
+    void testEmptySearchString();
+    void testAllVideos();
 
+    void testFileNameSearch();
 private:
     QTemporaryDir* m_tempDir;
     Database* m_db;
     FileSearchStore* m_store;
 
     uint insertUrl(const QString& url);
+    void insertType(int id, const QString& type);
+    void insertExactText(int id, const QString& text, const QString& prefix);
     void insertText(int id, const QString& text);
     void insertRating(int id, int rating);
 };
