@@ -222,7 +222,7 @@ QStringList QueryParser::Private::split(const QString &query, bool is_user_query
     for (int i=0; i<size; ++i) {
         QChar c = query.at(i);
 
-        if (!between_quotes && (is_user_query || part != QLatin1String("$")) &&
+        if (!between_quotes && (is_user_query || part != QLatin1String("%")) &&
             (split_at_every_char || c.isSpace() || (is_user_query && separators.contains(c)))) {
             // If there is a cluster of several spaces in the input, part may be empty
             if (part.size() > 0) {
@@ -266,24 +266,24 @@ QStringList QueryParser::Private::split(const QString &query, bool is_user_query
 void QueryParser::Private::runPasses(int cursor_position, QueryParser::ParserFlags flags)
 {
     // Prepare literal values
-    runPass(pass_splitunits, cursor_position, QLatin1String("$1"));
-    runPass(pass_numbers, cursor_position, QLatin1String("$1"));
-    runPass(pass_filesize, cursor_position, QLatin1String("$1 $2"));
-    runPass(pass_typehints, cursor_position, QLatin1String("$1"));
+    runPass(pass_splitunits, cursor_position, QLatin1String("%1"));
+    runPass(pass_numbers, cursor_position, QLatin1String("%1"));
+    runPass(pass_filesize, cursor_position, QLatin1String("%1 %2"));
+    runPass(pass_typehints, cursor_position, QLatin1String("%1"));
 
     if (flags & DetectFilenamePattern) {
-        runPass(pass_filenames, cursor_position, QLatin1String("$1"));
+        runPass(pass_filenames, cursor_position, QLatin1String("%1"));
     }
 
     // Date-time periods
-    runPass(pass_periodnames, cursor_position, QLatin1String("$1"));
+    runPass(pass_periodnames, cursor_position, QLatin1String("%1"));
 
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Offset);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Adding an offset to a period of time ($1=period, $2=offset)", "in $2 $1"));
+        i18nc("Adding an offset to a period of time (%1=period, %2=offset)", "in %2 %1"));
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::InvertedOffset);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Removing an offset from a period of time ($1=period, $2=offset)", "$2 $1 ago"));
+        i18nc("Removing an offset from a period of time (%1=period, %2=offset)", "%2 %1 ago"));
 
     pass_dateperiods.setKind(PassDatePeriods::Day, PassDatePeriods::Offset, 1);
     runPass(pass_dateperiods, cursor_position,
@@ -300,42 +300,42 @@ void QueryParser::Private::runPasses(int cursor_position, QueryParser::ParserFla
 
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Value, 1);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("First period (first day, month, etc)", "first $1"),
+        i18nc("First period (first day, month, etc)", "first %1"),
         ki18n("First week, month, day, ..."));
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Value, -1);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Last period (last day, month, etc)", "last $1 of"),
+        i18nc("Last period (last day, month, etc)", "last %1 of"),
         ki18n("Last week, month, day, ..."));
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Value);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Setting the value of a period, as in 'third week' ($1=period, $2=value)", "$2 $1"));
+        i18nc("Setting the value of a period, as in 'third week' (%1=period, %2=value)", "%2 %1"));
 
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Offset, 1);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Adding 1 to a period of time", "next $1"),
+        i18nc("Adding 1 to a period of time", "next %1"),
         ki18n("Next week, month, day, ..."));
     pass_dateperiods.setKind(PassDatePeriods::VariablePeriod, PassDatePeriods::Offset, -1);
     runPass(pass_dateperiods, cursor_position,
-        i18nc("Removing 1 to a period of time", "last $1"),
+        i18nc("Removing 1 to a period of time", "last %1"),
         ki18n("Previous week, month, day, ..."));
 
     // Setting values of date-time periods (14:30, June 6, etc)
     pass_datevalues.setPm(true);
     runPass(pass_datevalues, cursor_position,
-        i18nc("An hour ($5) and an optional minute ($6), PM", "at $5 :|\\. $6 pm;at $5 h pm;at $5 pm;$5 : $6 pm;$5 h pm;$5 pm"),
+        i18nc("An hour (%5) and an optional minute (%6), PM", "at %5 :|\\. %6 pm;at %5 h pm;at %5 pm;%5 : %6 pm;%5 h pm;%5 pm"),
         ki18n("A time after midday"));
     pass_datevalues.setPm(false);
     runPass(pass_datevalues, cursor_position,
-        i18nc("An hour ($5) and an optional minute ($6), AM", "at $5 :|\\. $6 am;at $5 \\. $6;at $5 h am;at $5 am;at $5;$5 :|\\. $6 am;$5 : $6 : $7;$5 : $6;$5 h am;$5 h;$5 am"),
+        i18nc("An hour (%5) and an optional minute (%6), AM", "at %5 :|\\. %6 am;at %5 \\. %6;at %5 h am;at %5 am;at %5;%5 :|\\. %6 am;%5 : %6 : %7;%5 : %6;%5 h am;%5 h;%5 am"),
         ki18n("A time"));
 
     runPass(pass_datevalues, cursor_position, i18nc(
-        "A year ($1), month ($2), day ($3), day of week ($4), hour ($5), "
-            "minute ($6), second ($7), in every combination supported by your language",
-        "$3 of $2 $1;$3 st|nd|rd|th $2 $1;$3 st|nd|rd|th of $2 $1;"
-        "$3 of $2;$3 st|nd|rd|th $2;$3 st|nd|rd|th of $2;$2 $3 st|nd|rd|th;$2 $3;$2 $1;"
-        "$1 - $2 - $3;$1 - $2;$3 / $2 / $1;$3 / $2;"
-        "in $2 $1; in $1;, $1"
+        "A year (%1), month (%2), day (%3), day of week (%4), hour (%5), "
+            "minute (%6), second (%7), in every combination supported by your language",
+        "%3 of %2 %1;%3 st|nd|rd|th %2 %1;%3 st|nd|rd|th of %2 %1;"
+        "%3 of %2;%3 st|nd|rd|th %2;%3 st|nd|rd|th of %2;%2 %3 st|nd|rd|th;%2 %3;%2 %1;"
+        "%1 - %2 - %3;%1 - %2;%3 / %2 / %1;%3 / %2;"
+        "in %2 %1; in %1;, %1"
     ));
 
     // Fold date-time properties into real DateTime values
@@ -343,99 +343,99 @@ void QueryParser::Private::runPasses(int cursor_position, QueryParser::ParserFla
 
     // Decimal values
     runPass(pass_decimalvalues, cursor_position,
-        i18nc("Decimal values with an integer ($1) and decimal ($2) part", "$1 \\. $2"),
+        i18nc("Decimal values with an integer (%1) and decimal (%2) part", "%1 \\. %2"),
         ki18n("A decimal value")
     );
 
     // Comparators
     pass_comparators.setComparator(Term::Contains);
     runPass(pass_comparators, cursor_position,
-        i18nc("Equality", "contains|containing $1"),
+        i18nc("Equality", "contains|containing %1"),
         ki18n("Containing"));
     pass_comparators.setComparator(Term::Greater);
     runPass(pass_comparators, cursor_position,
-        i18nc("Strictly greater", "greater|bigger|more than $1;at least $1;> $1"),
+        i18nc("Strictly greater", "greater|bigger|more than %1;at least %1;> %1"),
         ki18n("Greater than"));
     runPass(pass_comparators, cursor_position,
-        i18nc("After in time", "after|since $1"),
+        i18nc("After in time", "after|since %1"),
         ki18n("After"), CompletionProposal::DateTime);
     pass_comparators.setComparator(Term::Less);
     runPass(pass_comparators, cursor_position,
-        i18nc("Strictly smaller", "smaller|less|lesser than $1;at most $1;< $1"),
+        i18nc("Strictly smaller", "smaller|less|lesser than %1;at most %1;< %1"),
         ki18n("Smaller than"));
     runPass(pass_comparators, cursor_position,
-        i18nc("Before in time", "before|until $1"),
+        i18nc("Before in time", "before|until %1"),
         ki18n("Before"), CompletionProposal::DateTime);
     pass_comparators.setComparator(Term::Equal);
     runPass(pass_comparators, cursor_position,
-        i18nc("Equality", "equal|equals|= $1;equal to $1"),
+        i18nc("Equality", "equal|equals|= %1;equal to %1"),
         ki18n("Equal to"));
 
     // Properties associated with any Baloo resource
     pass_properties.setProperty(QLatin1String("rating"), PassProperties::Integer);
     runPass(pass_properties, cursor_position,
-        i18nc("Numeric rating of a resource", "rated as $1;rated $1;score is $1;score|scored $1;having $1 stars|star"),
+        i18nc("Numeric rating of a resource", "rated as %1;rated %1;score is %1;score|scored %1;having %1 stars|star"),
         ki18n("Rating (0 to 10)"), CompletionProposal::NoType);
     pass_properties.setProperty(QLatin1String("usercomment"), PassProperties::String);
     runPass(pass_properties, cursor_position,
-        i18nc("Comment of a resource", "described as $1;description|comment is $1;described|description|comment $1"),
+        i18nc("Comment of a resource", "described as %1;description|comment is %1;described|description|comment %1"),
         ki18n("Comment or description"), CompletionProposal::NoType);
 
     // Email-related properties
     pass_properties.setProperty(QLatin1String("from"), PassProperties::EmailAddress);
     runPass(pass_properties, cursor_position,
-        i18nc("Sender of an e-mail", "sent by $1;from $1;sender is $1;sender $1"),
+        i18nc("Sender of an e-mail", "sent by %1;from %1;sender is %1;sender %1"),
         ki18n("Sender of an e-mail"), CompletionProposal::Email);
     pass_properties.setProperty(QLatin1String("subject"), PassProperties::String);
     runPass(pass_properties, cursor_position,
-        i18nc("Subject of an e-mail or note", "title|subject is $1;title|subject $1;titled $1"),
+        i18nc("Subject of an e-mail or note", "title|subject is %1;title|subject %1;titled %1"),
         ki18n("Subject"));
     pass_properties.setProperty(QLatin1String("to"), PassProperties::EmailAddress);
     runPass(pass_properties, cursor_position,
-        i18nc("Recipient of an e-mail", "sent to $1;to $1;recipient is $1;recipient $1"),
+        i18nc("Recipient of an e-mail", "sent to %1;to %1;recipient is %1;recipient %1"),
         ki18n("Recipient of an e-mail"), CompletionProposal::Email);
     pass_properties.setProperty(QLatin1String("_k_datesent"), PassProperties::DateTime);
     runPass(pass_properties, cursor_position,
-        i18nc("Sending date-time", "sent at|on $1;sent $1"),
+        i18nc("Sending date-time", "sent at|on %1;sent %1"),
         ki18n("Date of sending"), CompletionProposal::DateTime);
     pass_properties.setProperty(QLatin1String("_k_datereceived"), PassProperties::DateTime);
     runPass(pass_properties, cursor_position,
-        i18nc("Receiving date-time", "received at|on $1;received $1;reception is $1"),
+        i18nc("Receiving date-time", "received at|on %1;received %1;reception is %1"),
         ki18n("Date of reception"), CompletionProposal::DateTime);
 
     // File-related properties
     pass_properties.setProperty(QLatin1String("author"), PassProperties::Contact);
     runPass(pass_properties, cursor_position,
-        i18nc("Author of a document", "written|created|composed by $1;author is $1;by $1"),
+        i18nc("Author of a document", "written|created|composed by %1;author is %1;by %1"),
         ki18n("Author"), CompletionProposal::Contact);
     pass_properties.setProperty(QLatin1String("size"), PassProperties::IntegerOrDouble);
     runPass(pass_properties, cursor_position,
-        i18nc("Size of a file", "size is $1;size $1;being $1 large;$1 large"),
+        i18nc("Size of a file", "size is %1;size %1;being %1 large;%1 large"),
         ki18n("Size"));
     pass_properties.setProperty(QLatin1String("filename"), PassProperties::String);
     runPass(pass_properties, cursor_position,
-        i18nc("Name of a file or contact", "name is $1;name $1;named $1"),
+        i18nc("Name of a file or contact", "name is %1;name %1;named %1"),
         ki18n("Name"));
     pass_properties.setProperty(QLatin1String("_k_datecreated"), PassProperties::DateTime);
     runPass(pass_properties, cursor_position,
-        i18nc("Date of creation", "created|dated at|on|in|of $1;created|dated $1;creation date|time|datetime is $1"),
+        i18nc("Date of creation", "created|dated at|on|in|of %1;created|dated %1;creation date|time|datetime is %1"),
         ki18n("Date of creation"), CompletionProposal::DateTime);
     pass_properties.setProperty(QLatin1String("_k_datemodified"), PassProperties::DateTime);
     runPass(pass_properties, cursor_position,
-        i18nc("Date of last modification", "modified|edited at|on $1;modified|edited $1;modification|edition date|time|datetime is $1"),
+        i18nc("Date of last modification", "modified|edited at|on %1;modified|edited %1;modification|edition date|time|datetime is %1"),
         ki18n("Date of last modification"), CompletionProposal::DateTime);
 
     // Tags
     pass_properties.setProperty(QLatin1String("tags"), PassProperties::Tag);
     runPass(pass_properties, cursor_position,
-        i18nc("A document is associated with a tag", "tagged as $1;has tag $1;tag is $1;# $1"),
+        i18nc("A document is associated with a tag", "tagged as %1;has tag %1;tag is %1;# %1"),
         ki18n("Tag name"), CompletionProposal::Tag);
 
 #if 0
     // Different kinds of properties that need subqueries
     pass_subqueries.setProperty(QLatin1String("relatedto"));
     runPass(pass_subqueries, cursor_position,
-        i18nc("Related to a subquery", "related to $$ ,"),
+        i18nc("Related to a subquery", "related to %% ,"),
         ki18n("Match items related to others"));
 #endif
 }
